@@ -7,12 +7,15 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include "stdafx.h"
+#include <winsock2.h>
+#include <ws2tcpip.h>
+
 extern "C" {
 #include <afs/param.h>
 #include <afs/stds.h>
 }
 
-#include "stdafx.h"
 #include "help.h"
 
 
@@ -41,10 +44,9 @@ static BOOL IsWindowsNT (void)
 }
 
 
-
-void SetHelpPath(const char *pszDefaultHelpFilePath)
+void SetHelpPath(LPCTSTR pszDefaultHelpFilePath)
 {
-	CString str = pszDefaultHelpFilePath;
+    CString str(pszDefaultHelpFilePath);
 	int nIndex = str.ReverseFind('\\');
 	ASSERT(nIndex >= 0);
 
