@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi_alloc.c,v 1.11.6.5.2.1 2008/05/20 19:52:29 shadow Exp $");
 
 
 
@@ -19,7 +17,7 @@ RCSID
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs/afs_stats.h"	/* afs statistics */
 
-#ifndef AFS_FBSD_ENV
+
 
 #ifdef AFS_AIX41_ENV
 #include "sys/lockl.h"
@@ -113,6 +111,8 @@ afs_osi_Free(void *x, size_t asize)
     osi_linux_free(x);
 #elif defined(AFS_FBSD_ENV)
     osi_fbsd_free(x);
+#elif defined(AFS_OBSD44_ENV)
+    osi_obsd_Free(x, asize);
 #else
     AFS_KFREE((struct osimem *)x, asize);
 #endif
@@ -137,10 +137,10 @@ osi_FreeLargeSpace(void *adata)
 
     AFS_STATCNT(osi_FreeLargeSpace);
     afs_stats_cmperf.LargeBlocksActive--;
-    MObtainWriteLock(&osi_flplock, 322);
+    ObtainWriteLock(&osi_flplock, 322);
     ((struct osi_packet *)adata)->next = freePacketList;
     freePacketList = adata;
-    MReleaseWriteLock(&osi_flplock);
+    ReleaseWriteLock(&osi_flplock);
 }
 
 void
@@ -151,10 +151,10 @@ osi_FreeSmallSpace(void *adata)
 
     AFS_STATCNT(osi_FreeSmallSpace);
     afs_stats_cmperf.SmallBlocksActive--;
-    MObtainWriteLock(&osi_fsplock, 323);
+    ObtainWriteLock(&osi_fsplock, 323);
     ((struct osi_packet *)adata)->next = freeSmallList;
     freeSmallList = adata;
-    MReleaseWriteLock(&osi_fsplock);
+    ReleaseWriteLock(&osi_fsplock);
 }
 
 
@@ -168,7 +168,7 @@ osi_AllocLargeSpace(size_t size)
 
     AFS_STATCNT(osi_AllocLargeSpace);
     if (size > AFS_LRALLOCSIZ)
-	osi_Panic("osi_AllocLargeSpace: size=%d\n", size);
+	osi_Panic("osi_AllocLargeSpace: size=%d\n", (int)size);
     afs_stats_cmperf.LargeBlocksActive++;
     if (!freePacketList) {
 	char *p;
@@ -185,11 +185,11 @@ osi_AllocLargeSpace(size_t size)
 #endif
 	return p;
     }
-    MObtainWriteLock(&osi_flplock, 324);
+    ObtainWriteLock(&osi_flplock, 324);
     tp = freePacketList;
     if (tp)
 	freePacketList = tp->next;
-    MReleaseWriteLock(&osi_flplock);
+    ReleaseWriteLock(&osi_flplock);
     return (char *)tp;
 }
 
@@ -202,7 +202,7 @@ osi_AllocSmallSpace(size_t size)
 
     AFS_STATCNT(osi_AllocSmallSpace);
     if (size > AFS_SMALLOCSIZ)
-	osi_Panic("osi_AllocSmallS: size=%d\n", size);
+	osi_Panic("osi_AllocSmallS: size=%d\n", (int)size);
 
     if (!freeSmallList) {
 	afs_stats_cmperf.SmallBlocksAlloced++;
@@ -214,11 +214,11 @@ osi_AllocSmallSpace(size_t size)
         return (char *)tp;
     }
     afs_stats_cmperf.SmallBlocksActive++;
-    MObtainWriteLock(&osi_fsplock, 327);
+    ObtainWriteLock(&osi_fsplock, 327);
     tp = freeSmallList;
     if (tp)
 	freeSmallList = tp->next;
-    MReleaseWriteLock(&osi_fsplock);
+    ReleaseWriteLock(&osi_fsplock);
     return (char *)tp;
 }
 
@@ -257,4 +257,4 @@ shutdown_osinet(void)
 		 afs_stats_cmperf.SmallBlocksActive);
     }
 }
-#endif
+
