@@ -158,6 +158,7 @@ void set_staticaddrs(void);
 #ifdef AFS_DARWIN_ENV
 #ifdef AFS_DARWIN80_ENV
 #include <sys/ioctl.h>
+#include <sys/xattr.h>
 #endif
 #include <mach/mach.h>
 #ifndef AFS_DARWIN100_ENV
@@ -794,6 +795,24 @@ CreateCacheSubDir(char *basename, int dirNum)
     return (0);
 }
 
+static void
+SetNoBackupAttr(char *fullpn)
+{
+#ifdef AFS_DARWIN80_ENV
+    int ret;
+
+    ret = setxattr(fullpn, "com.apple.metadata:com_apple_backup_excludeItem",
+		   "com.apple.backupd", strlen("com.apple.backupd"), 0,
+		   XATTR_CREATE);
+    if(ret < 0)
+    {
+	if(errno != EEXIST)
+	    fprintf(stderr, "afsd: Warning: failed to set attribute to preclude cache backup: %s\n", strerror(errno));
+    }
+#endif
+    return;
+}
+
 static int
 MoveCacheFile(char *basename, int fromDir, int toDir, int cacheFile, 
 	      int maxDir)
@@ -827,6 +846,7 @@ MoveCacheFile(char *basename, int fromDir, int toDir, int cacheFile,
 	       from, to, ret, errno);
 	return -1;
     }
+    SetNoBackupAttr(to);
 
     /* Reset directory pointer; fix file counts */
     dir_for_V[cacheFile] = toDir;
@@ -1072,16 +1092,19 @@ doSweepAFSCache(int *vFilesFound,
 	     * Found the file holding the dcache entries.
 	     */
 	    missing_DCacheFile = 0;
+	    SetNoBackupAttr(fullpn_DCacheFile);
 	} else if (dirNum < 0 && strcmp(currp->d_name, VOLINFOFILE) == 0) {
 	    /*
 	     * Found the file holding the volume info.
 	     */
 	    missing_VolInfoFile = 0;
+	    SetNoBackupAttr(fullpn_VolInfoFile);
 	} else if (dirNum < 0 && strcmp(currp->d_name, CELLINFOFILE) == 0) {
 	    /*
 	     * Found the file holding the cell info.
 	     */
 	    missing_CellInfoFile = 0;
+	    SetNoBackupAttr(fullpn_CellInfoFile);
 	} else if ((strcmp(currp->d_name, ".") == 0)
 		   || (strcmp(currp->d_name, "..") == 0) ||
 #ifdef AFS_DECOSF_ENV
@@ -1161,6 +1184,7 @@ doSweepAFSCache(int *vFilesFound,
 			cache_dir_list[thisDir]++;
 			(*vFilesFound)++;
 		    }
+		    SetNoBackupAttr(fullpn_VFile);
 		}
 
 	    } else if (dir_for_V[vFileNum] >= maxDir
@@ -1515,9 +1539,7 @@ mainproc(struct cmd_syndesc *as, void *arock)
     static char rn[] = "afsd";	/*Name of this routine */
     afs_int32 code;		/*Result of fork() */
     int i;
-#ifndef AFS_CACHE_VNODE_PATH
     int currVFile;		/*Current AFS cache file number passed in */
-#endif
     int mountFlags;		/*Flags passed to mount() */
     int lookupResult;		/*Result of GetLocalCellName() */
     int cacheIteration;		/*How many times through cache verification */
@@ -2139,23 +2161,6 @@ mainproc(struct cmd_syndesc *as, void *arock)
 		     rn, vFilesFound, cacheFiles, cacheIteration);
 	} while ((vFilesFound < cacheFiles)
 		 && (cacheIteration < MAX_CACHE_LOOPS));
-#ifdef AFS_CACHE_VNODE_PATH
-	if (afsd_debug)
-	    printf
-		("%s: Calling AFSOP_CACHEBASEDIR with '%s'\n",
-		 rn, cacheBaseDir);
-	call_syscall(AFSOP_CACHEBASEDIR, cacheBaseDir);
-	if (afsd_debug)
-	    printf
-		("%s: Calling AFSOP_CACHEDIRS with %d dirs\n",
-		 rn, nFilesPerDir);
-	call_syscall(AFSOP_CACHEDIRS, nFilesPerDir);
-	if (afsd_debug)
-	    printf
-		("%s: Calling AFSOP_CACHEFILES with %d files\n",
-		 rn, cacheFiles);
-	call_syscall(AFSOP_CACHEFILES, cacheFiles);
-#endif
     } else if (afsd_verbose)
 	printf("%s: Using memory cache, not swept\n", rn);
 
@@ -2298,7 +2303,6 @@ mainproc(struct cmd_syndesc *as, void *arock)
     if (!(cacheFlags & AFSCALL_INIT_MEMCACHE))
 	call_syscall(AFSOP_VOLUMEINFO, fullpn_VolInfoFile);
 
-#ifndef AFS_CACHE_VNODE_PATH
     /*
      * Give the kernel the names of the AFS files cached on the workstation's
      * disk.
@@ -2314,7 +2318,7 @@ mainproc(struct cmd_syndesc *as, void *arock)
 			 (afs_uint32) (inode_for_V[currVFile] >> 32),
 			 (afs_uint32) (inode_for_V[currVFile] & 0xffffffff));
 #else
-#if defined(LINUX_USE_FH)
+#if defined(LINUX_USE_FH) || defined(AFS_CACHE_VNODE_PATH)
 	    sprintf(fullpn_VFile, "%s/D%d/V%d", cacheBaseDir, dir_for_V[currVFile], currVFile);
 	    call_syscall(AFSOP_CACHEFILE, fullpn_VFile);
 #else
@@ -2322,7 +2326,6 @@ mainproc(struct cmd_syndesc *as, void *arock)
 #endif
 #endif
 	}
-#endif
 
     /*end for */
     /*
