@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bucoord/volstub.c,v 1.6.14.2 2007/01/05 03:32:24 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -24,9 +22,12 @@ RCSID
 #include <rx/xdr.h>
 #include <afs/vlserver.h>	/*Misc server-side Volume Location stuff */
 #include <ubik.h>
-#include "volser.h"
+#include <afs/volser.h>
 #include "bc.h"
 #include <afs/volint.h>
+#include <afs/volser.h>
+#include <afs/volser_prototypes.h>
+#include <afs/com_err.h>
 
 extern char *whoami;
 
@@ -35,11 +36,8 @@ extern char *whoami;
 /* ********************************************************************* */
 
 afs_int32
-bc_GetEntryByID(uclient, volID, volType, vldbEntryPtr)
-     struct ubik_client *uclient;
-     afs_int32 volID;
-     afs_int32 volType;
-     struct vldbentry *vldbEntryPtr;
+bc_GetEntryByID(struct ubik_client *uclient, afs_int32 volID, 
+		afs_int32 volType, struct vldbentry *vldbEntryPtr)
 {
     afs_int32 code = 0;
 
@@ -59,12 +57,8 @@ bc_GetEntryByID(uclient, volID, volType, vldbEntryPtr)
  */
 
 afs_int32
-volImageTime(serv, part, volid, voltype, clDatePtr)
-     afs_int32 serv;
-     afs_int32 part;
-     afs_int32 volid;
-     afs_int32 voltype;
-     afs_int32 *clDatePtr;
+volImageTime(afs_int32 serv, afs_int32 part, afs_int32 volid, 
+	     afs_int32 voltype, afs_int32 *clDatePtr)
 {
     afs_int32 code = 0;
     struct volintInfo *viptr;
@@ -76,7 +70,7 @@ volImageTime(serv, part, volid, voltype, clDatePtr)
 
     code = UV_ListOneVolume(htonl(serv), part, volid, &viptr);
     if (code) {
-	com_err(whoami, code,
+	afs_com_err(whoami, code,
 		"Warning: Can't get clone time of volume %u - using 0",
 		volid);
 	*clDatePtr = 0;
@@ -98,7 +92,7 @@ volImageTime(serv, part, volid, voltype, clDatePtr)
 	break;
 
     default:
-	com_err(whoami, 0,
+	afs_com_err(whoami, 0,
 		"Can't get clone time of volume %u - unknown volume type",
 		volid);
 	return (-1);
