@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/budb/dbs_dump.c,v 1.11.14.4 2008/07/19 06:15:01 rra Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -40,10 +38,13 @@ RCSID
 #include "budb.h"
 #include "budb_errs.h"
 #include "database.h"
+#include "budb_internal.h"
 #include "error_macros.h"
 #include "globals.h"
 #include "afs/audit.h"
 
+afs_int32 DumpDB(struct rx_call *, int, afs_int32, charListT *, afs_int32 *);
+afs_int32 RestoreDbHeader(struct rx_call *, struct DbHeader *);
 void *dumpWatcher(void *);
 
 /* dump ubik database - interface routines */
@@ -53,8 +54,7 @@ void *dumpWatcher(void *);
  */
 
 afs_int32
-badEntry(dbAddr)
-     afs_uint32 dbAddr;
+badEntry(afs_uint32 dbAddr)
 {
     /* return entry ok */
     return (0);
@@ -67,7 +67,7 @@ badEntry(dbAddr)
 void *
 setupDbDump(void *param)
 {
-    int writeFid = (int)param;
+    int writeFid = (intptr_t)param;
     afs_int32 code = 0;
 
     code = InitRPC(&dumpSyncPtr->ut, LOCKREAD, 1);
@@ -87,18 +87,13 @@ setupDbDump(void *param)
   error_exit:
     if (dumpSyncPtr->ut)
 	ubik_EndTrans(dumpSyncPtr->ut);
-    return (void *)(code);
+    return (void *)(intptr_t)(code);
 }
 
 
-afs_int32 DumpDB(), RestoreDbHeader();
 afs_int32
-SBUDB_DumpDB(call, firstcall, maxLength, charListPtr, done)
-     struct rx_call *call;
-     int firstcall;
-     afs_int32 maxLength;
-     charListT *charListPtr;
-     afs_int32 *done;
+SBUDB_DumpDB(struct rx_call *call, int firstcall, afs_int32 maxLength, 
+	     charListT *charListPtr, afs_int32 *done)
 {
     afs_int32 code;
 
@@ -108,12 +103,11 @@ SBUDB_DumpDB(call, firstcall, maxLength, charListPtr, done)
 }
 
 afs_int32
-DumpDB(call, firstcall, maxLength, charListPtr, done)
-     struct rx_call *call;
-     int firstcall;		/* 1 - init.  0 - no init */
-     afs_int32 maxLength;
-     charListT *charListPtr;
-     afs_int32 *done;
+DumpDB(struct rx_call *call,
+       int firstcall,		/* 1 - init.  0 - no init */
+       afs_int32 maxLength,
+       charListT *charListPtr,
+       afs_int32 *done)
 {
 #ifdef AFS_PTHREAD_ENV
     pthread_t dumperPid, watcherPid;
@@ -179,7 +173,7 @@ DumpDB(call, firstcall, maxLength, charListPtr, done)
 #else
 	code =
 	    LWP_CreateProcess(setupDbDump, 16384, 1,
-			      (void *)dumpSyncPtr->pipeFid[1],
+			      (void *)(intptr_t)dumpSyncPtr->pipeFid[1],
 			      "Database Dumper", &dumperPid);
 	if (code)
 	    goto error_exit;
@@ -275,9 +269,7 @@ DumpDB(call, firstcall, maxLength, charListPtr, done)
 }
 
 afs_int32
-SBUDB_RestoreDbHeader(call, header)
-     struct rx_call *call;
-     struct DbHeader *header;
+SBUDB_RestoreDbHeader(struct rx_call *call, struct DbHeader *header)
 {
     afs_int32 code;
 
@@ -287,9 +279,7 @@ SBUDB_RestoreDbHeader(call, header)
 }
 
 afs_int32
-RestoreDbHeader(call, header)
-     struct rx_call *call;
-     struct DbHeader *header;
+RestoreDbHeader(struct rx_call *call, struct DbHeader *header)
 {
     struct ubik_trans *ut = 0;
     afs_int32 code = 0;
