@@ -10,6 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wimplicit-function-declaration"
+#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -57,6 +60,8 @@
 #define XBSA_TCMAIN
 #include "butc_xbsa.h"
 #include "butc_prototypes.h"
+#include <afs/kautils.h>
+#include <afs/bc.h>
 
 #define N_SECURITY_OBJECTS 3
 #define ERRCODE_RANGE 8		/* from error_table.h */
@@ -325,8 +330,8 @@ GetDeviceConfig(char *filename, struct tapeConfig *config, afs_int32 portOffset)
     char devName[LINESIZE], tcapacity[LINESIZE], tfmsize[LINESIZE],
 	trest[LINESIZE];
     afs_int32 aport;
-    afs_uint32 capacity;
-    afs_uint32 fmSize;
+    afs_int32 capacity;
+    afs_int32 fmSize;
     afs_int32 code = 0, count;
 
     /* Initialize the config struct */
