@@ -20,6 +20,7 @@
 #define AFS_SUN57_ENV		1
 #define AFS_SUN58_ENV		1
 #define AFS_SUN59_ENV		1
+#define AFS_BOZONLOCK_ENV       1
 
 #define AFS_64BIT_ENV		1	/* Defines afs_int32 as int, not long. */
 #define AFS_64BIT_CLIENT	1	
@@ -51,6 +52,7 @@
 #define AFS_HAVE_FFS    1	/* Use system's ffs. */
 #define AFS_HAVE_VXFS	1	/* Support cache on Veritas vxfs file system */
 #define AFS_HAVE_STATVFS 1	/* System supports statvfs */
+#define AFS_HAVE_STATVFS64	1	/* System supports statvfs64 */
 #define AFS_VM_RDWR_ENV	1	/* read/write implemented via VM */
 #define AFS_USE_GETTIMEOFDAY 1	/* use gettimeofday to implement rx clock */
 
@@ -68,10 +70,9 @@
 /* sun definitions here */
 #define	AFS_UIOFMODE		1	/* Only in afs/afs_vnodeops.c (afs_ustrategy) */
 #define	AFS_SYSVLOCK		1	/* sys v locking supported */
-/*#define	AFS_USEBUFFERS	1*/
 #define	afsio_iov		uio_iov
 #define	afsio_iovcnt	uio_iovcnt
-#define	afsio_offset	uio_offset
+#define	afsio_offset	uio_loffset
 #define	afsio_seg		uio_segflg
 #define	afsio_fmode	uio_fmode
 #define	afsio_resid	uio_resid
@@ -79,7 +80,7 @@
 #define	AFS_UIOUSER	UIO_USERSPACE
 #define	AFS_CLBYTES	MCLBYTES
 #define	AFS_MINCHANGE	2
-#define	osi_GetTime(x)	uniqtime(x)
+#define	osi_GetTime(x)	uniqtime32(x)
 
 /**
   * These defines are for the 64 bit Solaris 7 port
@@ -91,17 +92,6 @@
 #define AFS_64BIT_INO   	1
 #endif
 
-/**
-  * Solaris 7 64 bit has two versions of uniqtime. Since we consistently
-  * use 32 bit quantities for time in afs, we now use uniqtime32
-  */
-#if defined(AFS_SUN57_64BIT_ENV)
-#undef osi_GetTime
-#define osi_GetTime(x)  uniqtime32(x)
-#endif
-
-
-
 #define	AFS_KALLOC(n)	kmem_alloc(n, KM_SLEEP)
 #define AFS_KALLOC_NOSLEEP(n)   kmem_alloc(n, KM_NOSLEEP)
 #define	AFS_KFREE	kmem_free
@@ -166,7 +156,6 @@
 #ifdef KERNEL
 #define	AFS_UIOFMODE		1	/* Only in afs/afs_vnodeops.c (afs_ustrategy) */
 #define	AFS_SYSVLOCK		1	/* sys v locking supported */
-/*#define	AFS_USEBUFFERS	1*/
 #define	afsio_iov	uio_iov
 #define	afsio_iovcnt	uio_iovcnt
 #define	afsio_offset	uio_offset
