@@ -12,14 +12,19 @@
 #define DES_DEFS
 
 #if defined(UKERNEL)
-#include "../des/mit-cpyright.h"
+#include "des/mit-cpyright.h"
 #else /* defined(UKERNEL) */
-#include <mit-cpyright.h>
+#include "mit-cpyright.h"
 #endif /* defined(UKERNEL) */
 
 typedef unsigned char des_cblock[8];	/* crypto-block size */
 /* Key schedule */
-typedef struct des_ks_struct { des_cblock _; } des_key_schedule[16];
+typedef struct des_ks_struct {
+    union {
+    afs_uint32 i[2];
+    des_cblock _;
+    } _;
+} des_key_schedule[16];
 
 #define DES_KEY_SZ 	(sizeof(des_cblock))
 #define DES_ENCRYPT	1
