@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.19 2006/02/01 16:09:18 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -26,13 +24,7 @@ RCSID
 #include "kalog.h"		/* for OpenLog() */
 #include <time.h>
 #include <stdio.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -42,23 +34,32 @@ RCSID
 #include <lwp.h>
 #include <rx/xdr.h>
 #include <rx/rx.h>
+#include <rx/rxstat.h>
 #include <rx/rxkad.h>
 #include <rx/rx_globals.h>
 #include <afs/cellconfig.h>
 #include <lock.h>
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
+#include <afs/audit.h>
 #include <ubik.h>
 #include <sys/stat.h>
 #include "kauth.h"
+#include "kauth_internal.h"
 #include "kautils.h"
 #include "kaserver.h"
-
+#include "kadatabase.h"
+#include "kaprocs.h"
 
 struct kadstats dynamic_statistics;
 struct ubik_dbase *KA_dbase;
 afs_int32 myHost = 0;
 afs_int32 verbose_track = 1;
 afs_int32 krb4_cross = 0;
+afs_int32 rxBind = 0;
+
+#define ADDRSPERSITE 16         /* Same global is in rx/rx_user.c */
+afs_uint32 SHostAddrs[ADDRSPERSITE];
 
 struct afsconf_dir *KA_conf;	/* for getting cell info */
 
@@ -75,8 +76,7 @@ static int debugOutput;
 
 /* check whether caller is authorized to manage RX statistics */
 int
-KA_rxstat_userok(call)
-     struct rx_call *call;
+KA_rxstat_userok(struct rx_call *call)
 {
     return afsconf_SuperUser(KA_conf, call, NULL);
 }
@@ -95,7 +95,7 @@ es_Report(char *fmt, ...)
 }
 
 static void
-initialize_dstats()
+initialize_dstats(void)
 {
     memset(&dynamic_statistics, 0, sizeof(dynamic_statistics));
     dynamic_statistics.start_time = time(0);
@@ -103,10 +103,8 @@ initialize_dstats()
 }
 
 static int
-convert_cell_to_ubik(cellinfo, myHost, serverList)
-     struct afsconf_cell *cellinfo;
-     afs_int32 *myHost;
-     afs_int32 *serverList;
+convert_cell_to_ubik(struct afsconf_cell *cellinfo, afs_int32 *myHost,
+		     afs_int32 *serverList)
 {
     int i;
     char hostname[64];
@@ -131,10 +129,7 @@ convert_cell_to_ubik(cellinfo, myHost, serverList)
 }
 
 static afs_int32
-kvno_admin_key(rock, kvno, key)
-     char *rock;
-     afs_int32 kvno;
-     struct ktc_encryptionKey *key;
+kvno_admin_key(void *rock, afs_int32 kvno, struct ktc_encryptionKey *key)
 {
     return ka_LookupKvno(0, KA_ADMIN_NAME, KA_ADMIN_INST, kvno, key);
 
@@ -150,9 +145,8 @@ kvno_admin_key(rock, kvno, key)
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     int argc;
-     char *argv[];
+int
+main(int argc, char *argv[])
 {
     afs_int32 code;
     char *whoami = argv[0];
@@ -168,20 +162,14 @@ main(argc, argv)
     int level;			/* security level for Ubik */
     afs_int32 i;
     char clones[MAXHOSTSPERCELL];
+    afs_uint32 host = ntohl(INADDR_ANY);
+    char *auditFileName = NULL;
 
     struct rx_service *tservice;
     struct rx_securityClass *sca[1];
     struct rx_securityClass *scm[3];
 
-    extern int afsconf_ClientAuthSecure();
-    extern int afsconf_ServerAuth();
-    extern int afsconf_CheckAuth();
-
     extern int rx_stackSize;
-    extern int KAA_ExecuteRequest();
-    extern int KAT_ExecuteRequest();
-    extern int KAM_ExecuteRequest();
-    extern int RXSTATS_ExecuteRequest();
 
 #ifdef	AFS_AIX32_ENV
     /*
@@ -203,9 +191,9 @@ main(argc, argv)
     if (argc == 0) {
       usage:
 	printf("Usage: kaserver [-noAuth] [-fastKeys] [-database <dbpath>] "
-	       "[-auditlog <log path>] "
-	       "[-localfiles <lclpath>] [-minhours <n>] [-servers <serverlist>] "
-	       "[-crossrealm]"
+	       "[-auditlog <log path>] [-audit-interface <file|sysvmq>] "
+	       "[-rxbind] [-localfiles <lclpath>] [-minhours <n>] "
+	       "[-servers <serverlist>] [-crossrealm] "
 	       /*" [-enable_peer_stats] [-enable_process_stats] " */
 	       "[-help]\n");
 	exit(1);
@@ -249,34 +237,16 @@ main(argc, argv)
 		lclpath = dbpath;
 	}
 	else if (strncmp(arg, "-auditlog", arglen) == 0) {
-	    int tempfd, flags;
-	    FILE *auditout;
-	    char oldName[MAXPATHLEN];
-	    char *fileName = argv[++a];
-	    
-#ifndef AFS_NT40_ENV
-	    struct stat statbuf;
-	    
-	    if ((lstat(fileName, &statbuf) == 0) 
-		&& (S_ISFIFO(statbuf.st_mode))) {
-		flags = O_WRONLY | O_NONBLOCK;
-	    } else 
-#endif
-	    {
-		strcpy(oldName, fileName);
-		strcat(oldName, ".old");
-		renamefile(fileName, oldName);
-		flags = O_WRONLY | O_TRUNC | O_CREAT;
+	    auditFileName = argv[++a];
+
+	} else if (strncmp(arg, "-audit-interface", arglen) == 0) {
+	    char *interface = argv[++a];
+
+	    if (osi_audit_interface(interface)) {
+		printf("Invalid audit interface '%s'\n", interface);
+		exit(1);
 	    }
-	    tempfd = open(fileName, flags, 0666);
-	    if (tempfd > -1) {
-		auditout = fdopen(tempfd, "a");
-		if (auditout) {
-		    osi_audit_file(auditout);
-		} else
-		    printf("Warning: auditlog %s not writable, ignored.\n", fileName);
-	    } else
-		printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+	    
 	} else if (strcmp(arg, "-localfiles") == 0)
 	    lclpath = argv[++a];
 	else if (strcmp(arg, "-servers") == 0)
@@ -305,6 +275,8 @@ main(argc, argv)
 	    verbose_track = 0;
 	else if (IsArg("-crossrealm"))
 	    krb4_cross = 1;
+	else if (IsArg("-rxbind"))
+	    rxBind = 1;
 	else if (IsArg("-minhours")) {
 	    MinHours = atoi(argv[++a]);
 	} else if (IsArg("-enable_peer_stats")) {
@@ -316,14 +288,19 @@ main(argc, argv)
 	    goto usage;
 	}
     }
-    if (code = ka_CellConfig(cellservdb))
+
+    if (auditFileName) {
+	osi_audit_file(auditFileName);
+    }
+
+    if ((code = ka_CellConfig(cellservdb)))
 	goto abort;
     cell = ka_LocalCell();
     KA_conf = afsconf_Open(cellservdb);
     if (!KA_conf) {
 	code = KANOCELLS;
       abort:
-	com_err(whoami, code, "Failed getting cell info");
+	afs_com_err(whoami, code, "Failed getting cell info");
 	exit(1);
     }
 #ifdef        AUTH_DBM_LOG
@@ -336,12 +313,20 @@ main(argc, argv)
     OpenLog(AFSDIR_SERVER_KALOG_FILEPATH);
     SetupLogSignals();
 #endif
+
+    fprintf(stderr, "%s: WARNING: kaserver is deprecated due to its weak security "
+	    "properties.  Migrating to a Kerberos 5 KDC is advised.  "
+	    "http://www.openafs.org/no-more-des.html\n", whoami);
+    ViceLog(0, ("WARNING: kaserver is deprecated due to its weak security properties.  "
+	    "Migrating to a Kerberos 5 KDC is advised.  "
+	    "http://www.openafs.org/no-more-des.html\n"));
+
     code =
 	afsconf_GetExtendedCellInfo(KA_conf, cell, AFSCONF_KAUTHSERVICE,
-				    &cellinfo, &clones);
+				    &cellinfo, clones);
     if (servers) {
-	if (code = ubik_ParseServerList(argc, argv, &myHost, serverList)) {
-	    com_err(whoami, code, "Couldn't parse server list");
+	if ((code = ubik_ParseServerList(argc, argv, &myHost, serverList))) {
+	    afs_com_err(whoami, code, "Couldn't parse server list");
 	    exit(1);
 	}
 	cellinfo.hostAddr[0].sin_addr.s_addr = myHost;
@@ -377,6 +362,26 @@ main(argc, argv)
     ubik_CheckRXSecurityRock = (char *)KA_conf;
 
     ubik_nBuffers = 80;
+
+    if (rxBind) {
+	afs_int32 ccode;
+        if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || 
+            AFSDIR_SERVER_NETINFO_FILEPATH) {
+            char reason[1024];
+            ccode = parseNetFiles(SHostAddrs, NULL, NULL,
+                                           ADDRSPERSITE, reason,
+                                           AFSDIR_SERVER_NETINFO_FILEPATH,
+                                           AFSDIR_SERVER_NETRESTRICT_FILEPATH);
+        } else 
+	{
+            ccode = rx_getAllAddr(SHostAddrs, ADDRSPERSITE);
+        }
+        if (ccode == 1) {
+            host = SHostAddrs[0];
+	    rx_InitHost(host, htons(AFSCONF_KAUTHPORT));
+	}
+    }
+
     if (servers)
 	code =
 	    ubik_ServerInit(myHost, htons(AFSCONF_KAUTHPORT), serverList,
@@ -384,10 +389,10 @@ main(argc, argv)
     else
 	code =
 	    ubik_ServerInitByInfo(myHost, htons(AFSCONF_KAUTHPORT), &cellinfo,
-				  &clones, dbpath, &KA_dbase);
+				  clones, dbpath, &KA_dbase);
 
     if (code) {
-	com_err(whoami, code, "Ubik init failed");
+	afs_com_err(whoami, code, "Ubik init failed");
 	exit(2);
     }
 
@@ -397,8 +402,8 @@ main(argc, argv)
     rx_SetNoJumbo();
 
     tservice =
-	rx_NewService(0, KA_AUTHENTICATION_SERVICE, "AuthenticationService",
-		      sca, 1, KAA_ExecuteRequest);
+	rx_NewServiceHost(host, 0, KA_AUTHENTICATION_SERVICE, 
+			  "AuthenticationService", sca, 1, KAA_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	ViceLog(0, ("Could not create Authentication rx service\n"));
 	exit(3);
@@ -406,8 +411,9 @@ main(argc, argv)
     rx_SetMinProcs(tservice, 1);
     rx_SetMaxProcs(tservice, 1);
 
+    
     tservice =
-	rx_NewService(0, KA_TICKET_GRANTING_SERVICE, "TicketGrantingService",
+	rx_NewServiceHost(host, 0, KA_TICKET_GRANTING_SERVICE, "TicketGrantingService",
 		      sca, 1, KAT_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	ViceLog(0, ("Could not create Ticket Granting rx service\n"));
@@ -421,7 +427,7 @@ main(argc, argv)
     scm[RX_SCINDEX_KAD] =
 	rxkad_NewServerSecurityObject(rxkad_crypt, 0, kvno_admin_key, 0);
     tservice =
-	rx_NewService(0, KA_MAINTENANCE_SERVICE, "Maintenance", scm, 3,
+	rx_NewServiceHost(host, 0, KA_MAINTENANCE_SERVICE, "Maintenance", scm, 3,
 		      KAM_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	ViceLog(0, ("Could not create Maintenance rx service\n"));
@@ -432,7 +438,7 @@ main(argc, argv)
     rx_SetStackSize(tservice, 10000);
 
     tservice =
-	rx_NewService(0, RX_STATS_SERVICE_ID, "rpcstats", scm, 3,
+	rx_NewServiceHost(host, 0, RX_STATS_SERVICE_ID, "rpcstats", scm, 3,
 		      RXSTATS_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	ViceLog(0, ("Could not create rpc stats rx service\n"));
@@ -451,13 +457,13 @@ main(argc, argv)
     if (init_kaprocs(lclpath, initFlags))
 	return -1;
 
-    if (code = init_krb_udp()) {
+    if ((code = init_krb_udp())) {
 	ViceLog(0,
 		("Failed to initialize UDP interface; code = %d.\n", code));
 	ViceLog(0, ("Running without UDP access.\n"));
     }
 
     ViceLog(0, ("Starting to process AuthServer requests\n"));
-    rx_ServerProc();		/* donate this LWP */
+    rx_ServerProc(NULL);		/* donate this LWP */
     return 0;
 }
