@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/ubik/uinit.c,v 1.7.8.1 2006/09/15 23:22:27 jaltman Exp $");
 
 #include <afs/stds.h>
 #ifdef AFS_NT40_ENV
@@ -28,13 +26,7 @@ RCSID
 #include <sys/statfs.h>
 #endif
 
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 
 #include <afs/dirpath.h>
 #include <errno.h>
@@ -48,14 +40,14 @@ RCSID
 #include <ubik.h>
 #include <afs/afsint.h>
 #include <afs/cmd.h>
-#include <rx/rxkad.h>
 
-/*
-  Get the appropriate type of ubik client structure out from the system.
-*/
+/*!
+ * \brief Get the appropriate type of ubik client structure out from the system.
+ */
 afs_int32
-ugen_ClientInit(int noAuthFlag, char *confDir, char *cellName, afs_int32 sauth,
-	       struct ubik_client **uclientp, int (*secproc) (),
+ugen_ClientInit(int noAuthFlag, const char *confDir, char *cellName, afs_int32 sauth,
+	       struct ubik_client **uclientp, 
+	       int (*secproc) (struct rx_securityClass *, afs_int32),
 	       char *funcName, afs_int32 gen_rxkad_level, 
 	       afs_int32 maxservers, char *serviceid, afs_int32 deadtime,
 	       afs_uint32 server, afs_uint32 port, afs_int32 usrvid)
@@ -102,7 +94,7 @@ ugen_ClientInit(int noAuthFlag, char *confDir, char *cellName, afs_int32 sauth,
 		    "%s: can't find cell %s's hosts in %s/%s\n",
 		    funcName, cellName, AFSDIR_SERVER_ETC_DIRPATH,
 		    AFSDIR_CELLSERVDB_FILE);
-	    exit(1);
+	    return -1;
 	}
     } else {			/* not -localauth */
 	tdir = afsconf_Open(confDir);
@@ -119,7 +111,7 @@ ugen_ClientInit(int noAuthFlag, char *confDir, char *cellName, afs_int32 sauth,
 		fprintf(stderr,
 			"%s: can't get local cellname, check %s/%s\n",
 			funcName, confDir, AFSDIR_THISCELL_FILE);
-		exit(1);
+		return -1;
 	    }
 	    cellName = cellstr;
 	}
@@ -130,7 +122,7 @@ ugen_ClientInit(int noAuthFlag, char *confDir, char *cellName, afs_int32 sauth,
 	    fprintf(stderr,
 		    "%s: can't find cell %s's hosts in %s/%s\n",
 		    funcName, cellName, confDir, AFSDIR_CELLSERVDB_FILE);
-	    exit(1);
+	    return -1;
 	}
 	if (noAuthFlag)		/* -noauth */
 	    scIndex = 0;
@@ -167,7 +159,7 @@ ugen_ClientInit(int noAuthFlag, char *confDir, char *cellName, afs_int32 sauth,
 	default:
 	    fprintf(stderr, "%s: unsupported security index %d\n",
 		    funcName, scIndex);
-	    exit(1);
+	    return -1;
 	    break;
 	}
     }
@@ -184,7 +176,7 @@ ugen_ClientInit(int noAuthFlag, char *confDir, char *cellName, afs_int32 sauth,
 	    fprintf(stderr,
 		    "%s: info.numServers=%d (> maxservers=%d)\n",
 		    funcName, info.numServers, maxservers);
-	    exit(1);
+	    return -1;
 	}
 	for (i = 0; i < info.numServers; i++) {
 	    serverconns[i] =
