@@ -18,8 +18,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/vfsck/setup.c,v 1.13.6.1 2007/10/30 15:16:48 shadow Exp $");
 
 #include <stdio.h>
 #include <string.h>
@@ -741,7 +739,7 @@ readsb(listerr)
 	if (memcmp
 	    ((char *)&sblock.fs_blank[0], (char *)&altsblock.fs_blank[0],
 	     MAXCSBUFS * sizeof(int))) {
-	    memset((char *)sblock.fs_blank, 0, sizeof(sblock.fs_blank));
+	    memset(sblock.fs_blank, 0, sizeof(sblock.fs_blank));
 	} else {
 #endif /* __alpha */
 	    badsb(listerr,
