@@ -17,7 +17,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vol/physio.c,v 1.5 2001/08/08 00:04:23 shadow Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -27,6 +26,7 @@ RCSID("$Header: /cvs/openafs/src/vol/physio.c,v 1.5 2001/08/08 00:04:23 shadow E
 #else
 #include <sys/file.h>
 #include <unistd.h>
+#include <string.h>
 #ifdef	AFS_SUN5_ENV
 #include <sys/fcntl.h>
 #endif
@@ -35,17 +35,16 @@ RCSID("$Header: /cvs/openafs/src/vol/physio.c,v 1.5 2001/08/08 00:04:23 shadow E
 #include <afs/afsint.h>
 #include <errno.h>
 #include <afs/afssyscalls.h>
-#include "ihandle.h"
 #include "nfs.h"
+#include "ihandle.h"
 #include "salvage.h"
-#include "afs/assert.h"
-#include "afs/dir.h"
+#include <afs/dir.h>
+#include <assert.h>
+#include "vol_internal.h"
 
 /* returns 0 on success, errno on failure */
-int ReallyRead (file, block, data)
-DirHandle     *	file;
-int 		block;
-char	      *	data;
+int
+ReallyRead(DirHandle * file, int block, char *data)
 {
     FdHandle_t *fdP;
     int code;
@@ -55,16 +54,16 @@ char	      *	data;
 	code = errno;
 	return code;
     }
-    if (FDH_SEEK(fdP, block*AFS_PAGESIZE, SEEK_SET) < 0) {
+    if (FDH_SEEK(fdP, block * AFS_PAGESIZE, SEEK_SET) < 0) {
 	code = errno;
 	FDH_REALLYCLOSE(fdP);
 	return code;
     }
-    code = FDH_READ(fdP, data, AFS_PAGESIZE);
+    code = FDH_READ(fdP, data, (afs_fsize_t) AFS_PAGESIZE);
     if (code != AFS_PAGESIZE) {
 	if (code < 0)
 	    code = errno;
-	else 
+	else
 	    code = EIO;
 	FDH_REALLYCLOSE(fdP);
 	return code;
@@ -74,10 +73,8 @@ char	      *	data;
 }
 
 /* returns 0 on success, errno on failure */
-int ReallyWrite (file, block, data)
-DirHandle     *	file;
-int 		block;
-char	      *	data;
+int
+ReallyWrite(DirHandle * file, int block, char *data)
 {
     FdHandle_t *fdP;
     extern int VolumeChanged;
@@ -90,16 +87,16 @@ char	      *	data;
 	code = errno;
 	return code;
     }
-    if (FDH_SEEK(fdP, block*AFS_PAGESIZE, SEEK_SET) < 0) {
+    if (FDH_SEEK(fdP, block * AFS_PAGESIZE, SEEK_SET) < 0) {
 	code = errno;
 	FDH_REALLYCLOSE(fdP);
 	return code;
     }
-    code = FDH_WRITE(fdP, data, AFS_PAGESIZE);
+    code = FDH_WRITE(fdP, data, (afs_fsize_t) AFS_PAGESIZE);
     if (code != AFS_PAGESIZE) {
 	if (code < 0)
 	    code = errno;
-	else 
+	else
 	    code = EIO;
 	FDH_REALLYCLOSE(fdP);
 	return code;
@@ -113,73 +110,66 @@ char	      *	data;
  * Create a handle to a directory entry and reference it (IH_INIT).
  * The handle needs to be dereferenced with the FidZap() routine.
  */
-SetSalvageDirHandle(dir, volume, device, inode)
-DirHandle *dir;
-afs_int32 volume;
-Inode inode;
-Device device;
+void
+SetSalvageDirHandle(DirHandle * dir, afs_int32 volume, Device device,
+		    Inode inode)
 {
-    static SalvageCacheCheck = 1;
+    static int SalvageCacheCheck = 1;
     memset(dir, 0, sizeof(DirHandle));
 
     dir->dirh_device = device;
     dir->dirh_volume = volume;
     dir->dirh_inode = inode;
-    IH_INIT(dir->dirh_handle, device, volume,  inode);
+    IH_INIT(dir->dirh_handle, device, volume, inode);
     /* Always re-read for a new dirhandle */
     dir->dirh_cacheCheck = SalvageCacheCheck++;
 }
 
-FidZap (file)
-DirHandle     *	file;
-
+void
+FidZap(DirHandle * file)
 {
     IH_RELEASE(file->dirh_handle);
     memset(file, 0, sizeof(DirHandle));
 }
 
-FidZero (file)
-DirHandle     *	file;
-
+void
+FidZero(DirHandle * file)
 {
     memset(file, 0, sizeof(DirHandle));
 }
 
-FidEq (afile, bfile)
-DirHandle      * afile;
-DirHandle      * bfile;
-
+int
+FidEq(DirHandle * afile, DirHandle * bfile)
 {
-    if (afile->dirh_volume != bfile->dirh_volume) return 0;
-    if (afile->dirh_device != bfile->dirh_device) return 0;
-    if (afile->dirh_cacheCheck != bfile->dirh_cacheCheck) return 0;
-    if (afile->dirh_inode != bfile->dirh_inode) return 0;
+    if (afile->dirh_volume != bfile->dirh_volume)
+	return 0;
+    if (afile->dirh_device != bfile->dirh_device)
+	return 0;
+    if (afile->dirh_cacheCheck != bfile->dirh_cacheCheck)
+	return 0;
+    if (afile->dirh_inode != bfile->dirh_inode)
+	return 0;
     return 1;
 }
 
-FidVolEq (afile, vid)
-DirHandle      * afile;
-afs_int32            vid;
-
+int
+FidVolEq(DirHandle * afile, afs_int32 vid)
 {
-    if (afile->dirh_volume != vid) return 0;
+    if (afile->dirh_volume != vid)
+	return 0;
     return 1;
 }
 
-FidCpy (tofile, fromfile)
-DirHandle      * tofile;
-DirHandle      * fromfile;
-
+void
+FidCpy(DirHandle * tofile, DirHandle * fromfile)
 {
     *tofile = *fromfile;
     IH_COPY(tofile->dirh_handle, fromfile->dirh_handle);
 }
 
-Die (msg)
-char  * msg;
-
+void
+Die(char *msg)
 {
-    printf("%s\n",msg);
-    assert(1==2);
+    printf("%s\n", msg);
+    assert(1 == 2);
 }
-
