@@ -110,7 +110,7 @@ typedef struct VnodeDiskObject {
 				 * backup purposes */
     afs_int32 group;		/* unix group */
     afs_int32 vn_ino_hi;	/* high part of 64 bit inode. */
-    bit32 reserved6;
+    bit32 vn_length_hi;         /* high part of 64 bit length */
     /* Missing:
      * archiving/migration
      * encryption key
@@ -155,6 +155,7 @@ enum VnFlags {
     VN_ON_HASH            = 0x1,        /**< vnode is on hash table */
     VN_ON_LRU             = 0x2,        /**< vnode is on lru list */
     VN_ON_VVN             = 0x4,        /**< vnode is on volume vnode list */
+    VN_FLAGS_END
 };
 
 
@@ -220,17 +221,10 @@ typedef struct Vnode {
 #define Vn_id(vnp)            ((vnp)->vnodeNumber)
 
 
-#ifdef AFS_LARGEFILE_ENV
-#define VN_GET_LEN(N, V) FillInt64(N, (V)->disk.reserved6, (V)->disk.length)
-#define VNDISK_GET_LEN(N, V) FillInt64(N, (V)->reserved6, (V)->length)
-#define VN_SET_LEN(V, N) SplitInt64(N, (V)->disk.reserved6, (V)->disk.length)
-#define VNDISK_SET_LEN(V, N) SplitInt64(N, (V)->reserved6, (V)->length)
-#else /* !AFS_LARGEFILE_ENV */
-#define VN_GET_LEN(N, V) (N) = (V)->disk.length;
-#define VNDISK_GET_LEN(N, V) (N) = (V)->length;
-#define VN_SET_LEN(V, N) (V)->disk.length = (N);
-#define VNDISK_SET_LEN(V, N) (V)->length = (N);
-#endif /* !AFS_LARGEFILE_ENV */
+#define VN_GET_LEN(N, V) FillInt64(N, (V)->disk.vn_length_hi, (V)->disk.length)
+#define VNDISK_GET_LEN(N, V) FillInt64(N, (V)->vn_length_hi, (V)->length)
+#define VN_SET_LEN(V, N) SplitInt64(N, (V)->disk.vn_length_hi, (V)->disk.length)
+#define VNDISK_SET_LEN(V, N) SplitInt64(N, (V)->vn_length_hi, (V)->length)
 
 #ifdef AFS_64BIT_IOPS_ENV
 #define VN_GET_INO(V) ((Inode)((V)->disk.vn_ino_lo | \
